#+BEGIN_COMMENT
.. title: Test cases limited to particular app for django
.. slug: test-cases-limited-to-particular-app-for-django
.. date: 2015-10-04 09:05:43 UTC
.. tags: django, tests, django-rest-framework, unittest
.. category: coding
.. link: 
.. description: Hack to disable other apps from INSTALLED_APPS to run tests faster
.. type: text
#+END_COMMENT
#+OPTIONS: ^:nil

At [[https://www.taxspanner.com/][TaxSpanner]] as we were entering the "filing season" we wanted an
continues integration system in place which could tests independent
apps and stage them for further testing. We setup jenkins, created
pipeline for different apps but as models grew and migrations were
getting added, the whole pipeline started crawling.

There are different moving parts in whole application, say app1, app2,
app3 and so on. While many of applications do interact with each other
using API's but somehow application level testing using manage.py
doesn't exactly limit things to just that particular app. What I mean
is, say I am working on app2 running its test using
#+BEGIN_SRC python
./apps/manage.py test app2
#+END_SRC
will still load all installed_apps and try to get your "test DB ready
with all models, indexes and migrations". With the complicated models
this preparing process itself was taking hours(2 hrs+). I am not sure
about what would be standard approach for such a setup, should we
"include" settings from each app individually? Anyway, so because of
that behavior of django's test suite we struggled and even started
avoiding writing/running tests.

Somedays back, as we started work on revamping an app around
django-rest-framework and I was again stuck at this issue. While
looking around I was just experimenting with settings and added this
"hack" at the end of settings.py
#+BEGIN_SRC python
import sys
if 'test' in sys.argv or 'test_coverage' in sys.argv:
    INSTALLED_APPS = ('app2', 'rest_framework', 'usermanagement',
                      'django.contrib.sites', 'registration',
                      'django.contrib.sitemaps',
                      'django.contrib.webdesign',)
#+END_SRC
and voila, my tests were back on track, under a minute(~10 seconds)
with no unrelated apps. There were further suggestions to make things
more faster by team :
#+BEGIN_SRC python
  DATABASES['default']['ENGINE'] = 'django.db.backends.sqlite3'
#+END_SRC
and further to avoid migrations, 
#+BEGIN_SRC python
  class DisableMigrations(object):
      def __contains__(self, item):
          return True

      def __getitem__(self, item):
          return "notmigrations"
  MIGRATION_MODULES = DisableMigrations()
#+END_SRC
